#!/usr/bin/python
# coding: UTF-8
# Rec10 TS Recording Tools
# Copyright (C) 2009 Yukikaze
import chdata
import timerec
chdata.new_chdata()
timerec.task()